]> granicus.if.org Git - sysstat/commitdiff
"sar -o" now collects all possible statistics
authorSebastien GODARD <sysstat@orange.fr.fake>
Sun, 30 Jun 2013 13:07:44 +0000 (15:07 +0200)
committerSebastien GODARD <sysstat@orange.fr.fake>
Sun, 30 Jun 2013 13:07:44 +0000 (15:07 +0200)
sar now collects all possible statistics (including partitions ones)
when data are saved into a file with option -o ("sar -o" calls sadc
with option "-S XALL" instead of "-S ALL").

sar.c

diff --git a/sar.c b/sar.c
index 9eafc6a743640093f6bdd32551de8df9b9ace78f..b03b486f2e7dcc3890331236dec6e0d71b869595 100644 (file)
--- a/sar.c
+++ b/sar.c
@@ -1400,9 +1400,9 @@ int main(int argc, char **argv)
                
                /* Writing data to a file (option -o) */
                if (to_file[0]) {
/* Collect all possible activities (option -S ALL for sadc) */
                        salloc(args_idx++, "-S");
-                       salloc(args_idx++, K_ALL);
+                       salloc(args_idx++, K_XALL);
                        /* Outfile arg */
                        salloc(args_idx++, to_file);
                }
@@ -1400,9 +1400,9 @@ int main(int argc, char **argv)
                /* Writing data to a file (option -o) */
                if (to_file[0]) {
-                       /* Collect all possible activities (option -S ALL for sadc) */
+                       /* Collect all possible activities (option -S XALL for sadc) */
                        salloc(args_idx++, "-S");